;; Generated package description from ffs.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "ffs" "0.2.2.0.20260521.115034" "Form feed-separated plain text presentations" '((emacs "27.1")) :commit "71b66bcf7e1538a28ca7b354e3e1acfd3d7da444" :authors '(("Amin Bandali" . "bandali@gnu.org")) :maintainer '("Amin Bandali" . "bandali@gnu.org") :keywords '("convenience" "focus" "narrowing" "outlines" "presentation" "text") :url "https://git.kelar.org/~bandali/ffs")
